==> ktp-accounts-kcm-0.6.2.tar.bz2: ktp-accounts-kcm-0.6.2/plugins/sunshine/ktpaccountskcm_plugin_sunshine.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for Gadu-Gadu accounts using the Sunshine connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju Gadu-Gadu korisničkih naloga koristeći Sunshine menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració de compte personalitzat per comptes del Gadu-Gadu que utilitzen el gestor de connexions Sunshine.
Comment[ca@valencia]=Interfície d'usuari de configuració de compte personalitzat per comptes del Gadu-Gadu que utilitzen el gestor de connexions Sunshine.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty Gadu-Gadu používající správce spojení Sunshine.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til Gadu-Gadu-konti der bruger forbindelseshåndteringen Sunshine.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Gadu-Gadu-Zugängen, die die Sunshine-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Sunshine.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas de Gadu-Gadu que usen el gestor de conexiones Sunshine.
Comment[et]=Sunshine'i ühendusehaldurit kasutavate Gadu-Gadu kontode kohandatud konto seadistamise kasutajaliides
Comment[fi]=Sunshine-yhteyshallintaa käyttävien Gadu-Gadu-tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur de configuration de comptes personnalisés pour les comptes Gadu-Gadu utilisant le gestionnaire de connexion Sunshine.
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas de Gadu-Gadu que empreguen o xestor de conexións Sunshine.
Comment[hu]=Egyedi beállítófelület a Sunshine kapcsolatkezelőt használó Gadu-Gadu azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Sunshine.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Sunshine.
Comment[kk]=Sunshine байланыс менеджерін қолданатын Gadu-Gadu тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​​គណនី​​ផ្ទាល់ខ្លួន​សម្រាប់​គណនី Gadu-Gadu ដែល​ប្រើ​កម្មវិធី​ការ​តភ្ជាប់ Sunshine ។
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja Gadu-Gadu paskyroms naudojant Sunshine ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte Gadu-Gadu-kontoer ved bruk av Sunshine tilkoblingsbehandler.
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor Gadu-Gadu accounts die de Sunshine verbindingenbeheerder gebruiken.
Comment[pl]=Własny interfejsu użytkownika konfiguracji kont dla kont wykorzystujących menadżera połączeń Gadu-Gadu.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Sunshine.
Comment[pt_BR]=Interface de configuração de contas personalizadas usando o gerenciador de conexões Gadu-Gadu.
Comment[ro]=Interfață personalizată de configurare a conturilor Gadu-Gadu folosind gestionarul de conexiuni Sunshine.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи Gadu-Gadu с помощью менеджера соединений Sunshine.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre Gadu-Gadu účty používajúce správcu pripojení Sunshine.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov Gadu-Gadu, ki uporabljajo upravljalnik povezav Sunshine.
Comment[sr]=Корисничко сучеље за подешавање посебних налога за гаду‑гаду налоге под менаџером везе Саншајн.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога за гаду‑гаду налоге под менаџером везе Саншајн.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga za gadu‑gadu naloge pod menadžerom veze Sunshine.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga za gadu‑gadu naloge pod menadžerom veze Sunshine.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av Gadu-Gadukonton som använder anslutningshanteraren Sunshine.
Comment[tr]=Sunshine bağlantı yöneticisi kullanan Gadu-Gadu hesapları için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштування облікового запису Gadu-Gadu за допомогою керування з’єднаннями Sunshine.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes Gadu-Gadu tot s' siervant do manaedjeu d' raloyaedje Sunshine.
Comment[x-test]=xxCustom account configuration user interface for Gadu-Gadu accounts using the Sunshine connection manager.xx
Comment[zh_CN]=通过 Sunshine 链接管理器自定义 Gadu-Gadu 账户的配置界面
Comment[zh_TW]=對使用 Sunshine 連線管理員的 Gadu-Gadu 帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Gadu-Gadu Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju Gadu-Gadu korisničkih naloga
Name[ca]=Interfície d'usuari de configuració de compte de Gadu-Gadu
Name[ca@valencia]=Interfície d'usuari de configuració de compte de Gadu-Gadu
Name[cs]=Uživatelské rozhraní nastavení účtu Gadu-Gadu
Name[da]=Brugerflade til Gadu-Gadu kontokonfiguration
Name[de]=Benutzeroberfläche zur Einrichtung von Gadu-Gadu-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη με Gadu-Gadu
Name[es]=Interfaz de configuración de cuentas Gadu-Gadu
Name[et]=Gadu-Gadu konto seadistamise kasutajaliides
Name[fi]=Gadu-Gadu-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur de configuration de comptes Gadu-Gadu
Name[gl]=Interface de usuario para a configuración de contas de Gadu-Gadu
Name[hu]=Gadu-Gadu azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Gadu-Gadu
Name[it]=Interfaccia utente di configurazione account Gadu-Gadu
Name[kk]=Gadu-Gadu тіркелгі пайдаланушы интерфейсін баптау
Name[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី Gadu-Gadu
Name[lt]=Gadu-Gadu paskyros konfigūravimo naudotojo sąsają
Name[nb]=Brukerflate for å sette opp Gadu-Gadu-konto
Name[nl]=Gebruikersinterface voor Gadu-Gadu accountconfiguratie
Name[pl]=Interfejs użytkownika konfiguracji konta Gadu-Gadu
Name[pt]=Interface de Configuração de Contas do Gadu-Gadu
Name[pt_BR]=Interface de configuração de contas do Gadu-Gadu
Name[ro]=Interfață de configurare a conturilor Gadu-Gadu
Name[ru]=Интерфейс для настройки учётной записи Gadu-Gadu
Name[sk]=Používateľské rozhranie konfigurácie účtu Gadu-Gadu
Name[sl]=Uporabniški vmesnik za nastavitev računov Gadu-Gadu
Name[sr]=Корисничко сучеље за подешавање гаду‑гаду налога
Name[sr@ijekavian]=Корисничко сучеље за подешавање гаду‑гаду налога
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje gadu‑gadu naloga
Name[sr@latin]=Korisničko sučelje za podešavanje gadu‑gadu naloga
Name[sv]=Användargränssnitt för inställning av Gadu-Gadukonton
Name[tr]=Gadu-Gadu Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштування Gadu-Gadu
Name[wa]=Eterface uzeu d' apontiaedje des contes Gadu-Gadu
Name[x-test]=xxGadu-Gadu Account Configuration User Interfacexx
Name[zh_CN]=Gadu-Gadu 账户用户配置界面
Name[zh_TW]=Gadu-Gadu 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_sunshine
X-KDE-PluginInfo-Author=Florian Reinhard
X-KDE-PluginInfo-Email=florian.reinhard@googlemail.com
X-KDE-PluginInfo-Name=sunshine
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true

==> ktp-accounts-kcm_0.8.0.orig.tar.bz2: ktp-accounts-kcm-0.8.0/plugins/sunshine/ktpaccountskcm_plugin_sunshine.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for Gadu-Gadu accounts using the Sunshine connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju Gadu-Gadu korisničkih naloga koristeći Sunshine menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració de compte personalitzat per comptes del Gadu-Gadu que utilitzen el gestor de connexions Sunshine.
Comment[ca@valencia]=Interfície d'usuari de configuració de compte personalitzat per comptes del Gadu-Gadu que utilitzen el gestor de connexions Sunshine.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty Gadu-Gadu používající správce spojení Sunshine.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til Gadu-Gadu-konti der bruger forbindelseshåndteringen Sunshine.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Gadu-Gadu-Zugängen, die die Sunshine-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Sunshine.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas de Gadu-Gadu que usen el gestor de conexiones Sunshine.
Comment[et]=Sunshine'i ühendusehaldurit kasutavate Gadu-Gadu kontode kohandatud konto seadistamise kasutajaliides
Comment[fi]=Sunshine-yhteyshallintaa käyttävien Gadu-Gadu-tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes « Gadu-Gadu » en utilisant le gestionnaire de connexions « Sunshine ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas de Gadu-Gadu que empreguen o xestor de conexións Sunshine.
Comment[hu]=Egyedi beállítófelület a Sunshine kapcsolatkezelőt használó Gadu-Gadu azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Sunshine.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Sunshine.
Comment[kk]=Sunshine байланыс менеджерін қолданатын Gadu-Gadu тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​​គណនី​​ផ្ទាល់ខ្លួន​សម្រាប់​គណនី Gadu-Gadu ដែល​ប្រើ​កម្មវិធី​ការ​តភ្ជាប់ Sunshine ។
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja Gadu-Gadu paskyroms naudojant Sunshine ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte Gadu-Gadu-kontoer ved bruk av Sunshine tilkoblingsbehandler.
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor Gadu-Gadu accounts die de Sunshine verbindingenbeheerder gebruiken.
Comment[pl]=Własny interfejsu użytkownika konfiguracji kont dla kont wykorzystujących menadżera połączeń Gadu-Gadu.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Sunshine.
Comment[pt_BR]=Interface de configuração de contas personalizadas usando o gerenciador de conexões Gadu-Gadu.
Comment[ro]=Interfață personalizată de configurare a conturilor Gadu-Gadu folosind gestionarul de conexiuni Sunshine.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи Gadu-Gadu с помощью менеджера соединений Sunshine.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre Gadu-Gadu účty používajúce správcu pripojení Sunshine.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov Gadu-Gadu, ki uporabljajo upravljalnik povezav Sunshine.
Comment[sr]=Корисничко сучеље за подешавање посебних налога за гаду‑гаду налоге под менаџером везе Саншајн.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога за гаду‑гаду налоге под менаџером везе Саншајн.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga za gadu‑gadu naloge pod menadžerom veze Sunshine.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga za gadu‑gadu naloge pod menadžerom veze Sunshine.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av Gadu-Gadukonton som använder anslutningshanteraren Sunshine.
Comment[tr]=Sunshine bağlantı yöneticisi kullanan Gadu-Gadu hesapları için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштування облікового запису Gadu-Gadu за допомогою керування з’єднаннями Sunshine.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes Gadu-Gadu tot s' siervant do manaedjeu d' raloyaedje Sunshine.
Comment[x-test]=xxCustom account configuration user interface for Gadu-Gadu accounts using the Sunshine connection manager.xx
Comment[zh_CN]=通过 Sunshine 链接管理器自定义 Gadu-Gadu 账户的配置界面
Comment[zh_TW]=對使用 Sunshine 連線管理員的 Gadu-Gadu 帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Gadu-Gadu Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju Gadu-Gadu korisničkih naloga
Name[ca]=Interfície d'usuari de configuració de compte de Gadu-Gadu
Name[ca@valencia]=Interfície d'usuari de configuració de compte de Gadu-Gadu
Name[cs]=Uživatelské rozhraní nastavení účtu Gadu-Gadu
Name[da]=Brugerflade til Gadu-Gadu kontokonfiguration
Name[de]=Benutzeroberfläche zur Einrichtung von Gadu-Gadu-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη με Gadu-Gadu
Name[es]=Interfaz de configuración de cuentas Gadu-Gadu
Name[et]=Gadu-Gadu konto seadistamise kasutajaliides
Name[fi]=Gadu-Gadu-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur pour la configuration de comptes « Gadu-Gadu ».
Name[gl]=Interface de usuario para a configuración de contas de Gadu-Gadu
Name[hu]=Gadu-Gadu azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Gadu-Gadu
Name[it]=Interfaccia utente di configurazione account Gadu-Gadu
Name[kk]=Gadu-Gadu тіркелгі пайдаланушы интерфейсін баптау
Name[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី Gadu-Gadu
Name[lt]=Gadu-Gadu paskyros konfigūravimo naudotojo sąsają
Name[nb]=Brukerflate for å sette opp Gadu-Gadu-konto
Name[nl]=Gebruikersinterface voor Gadu-Gadu accountconfiguratie
Name[pl]=Interfejs użytkownika konfiguracji konta Gadu-Gadu
Name[pt]=Interface de Configuração de Contas do Gadu-Gadu
Name[pt_BR]=Interface de configuração de contas do Gadu-Gadu
Name[ro]=Interfață de configurare a conturilor Gadu-Gadu
Name[ru]=Интерфейс для настройки учётной записи Gadu-Gadu
Name[sk]=Používateľské rozhranie konfigurácie účtu Gadu-Gadu
Name[sl]=Uporabniški vmesnik za nastavitev računov Gadu-Gadu
Name[sr]=Корисничко сучеље за подешавање гаду‑гаду налога
Name[sr@ijekavian]=Корисничко сучеље за подешавање гаду‑гаду налога
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje gadu‑gadu naloga
Name[sr@latin]=Korisničko sučelje za podešavanje gadu‑gadu naloga
Name[sv]=Användargränssnitt för inställning av Gadu-Gadukonton
Name[tr]=Gadu-Gadu Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштування Gadu-Gadu
Name[wa]=Eterface uzeu d' apontiaedje des contes Gadu-Gadu
Name[x-test]=xxGadu-Gadu Account Configuration User Interfacexx
Name[zh_CN]=Gadu-Gadu 账户用户配置界面
Name[zh_TW]=Gadu-Gadu 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_sunshine
X-KDE-PluginInfo-Author=Florian Reinhard
X-KDE-PluginInfo-Email=florian.reinhard@googlemail.com
X-KDE-PluginInfo-Name=sunshine
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
